from distutils.core import setup

setup(
    name = 'data-lake-plan',
    packages = ['data-lake-plan'],
    version = '0.0.1',  # Ideally should be same as your GitHub release tag varsion
    description = 'data lake plan excel',
    author = '',
    author_email = '',
    url = 'https://github.com/musicnova/DataLakePlan',
    download_url = 'https://github.com/musicnova/DataLakePlan/archive/0.0.1.tar.gz',
    keywords = ['data', 'lake'],
    classifiers = [],
)
